@@ -100,7 +100,7 @@ class MACallBack2(Callback):
     project_name = None
     model_tag = None
     
-    ma_period = 10
+    ma_period = 100
     
     def init(self,projectname,modeltag,model):
         self.project_name = projectname
@@ -159,6 +159,10 @@ class MACallBack2(Callback):
         if model_tag:
             trainlog = PathProxy2.getTrainProcessValues(projectname,model_tag)
             
+            tlog.add(trainlog,(train_loss,train_acc,train_mean,valid_loss,valid_acc,valid_mean))
+            
+            if epoch < ma_period:
+                return
             
             trainmodel = PathProxy2.getTrainCKPT(projectname,model_tag)
             validmodel = PathProxy2.getValidCKPT(projectname,model_tag)
@@ -180,6 +184,6 @@ class MACallBack2(Callback):
                 
                 MACallBack2.saveModelEpoch(validmodelpath,epoch)
             
-            tlog.add(trainlog,(train_loss,train_acc,train_mean,valid_loss,valid_acc,valid_mean))
+            
             
         pass
\ No newline at end of file
